@@ -123,6 +123,9 @@ const bool ConfigItems::load( const bool restore )
     ref_prefix_space = cf.get_option_int( "ref_prefix_space", CONF_REF_PREFIX_SPACE, 0, 16 );
     for( int i = 0; i < ref_prefix_space; ++i ) ref_prefix_space_str += " ";
 
+    // レスにアスキーアートがあると判定する正規表現
+    regex_res_aa = cf.get_option_str( "regex_res_aa", CONF_REGEX_RES_AA );
+
     // キャッシュのルートディレクトリ(旧バージョンとの互換のため残している)
     path_cacheroot = cf.get_option_str( "path_cacheroot", CONF_PATH_CACHEROOT );
 
@@ -476,6 +479,12 @@ const bool ConfigItems::load( const bool restore )
     // タブ上でマウスホイールを回転してタブを切り替える
     switchtab_wheel = cf.get_option_bool( "switchtab_wheel", CONF_SWITCHTAB_WHEEL );
 
+    // ビュー内から他のビューを開いたときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
+    newtab_pos = cf.get_option_int( "newtab_pos", CONF_NEWTAB_POS, 0, 2 );
+
+    // 次スレ検索を開くときのタブの位置 ( 0: 次スレ検索タブ 1:新しいタブ 2:アクティブなタブを置き換え -1:2.8.5以前の動作 )
+    boardnexttab_pos = cf.get_option_int( "boardnexttab_pos", CONF_BOARDNEXTTAB_POS, -1, 2 );
+
     // スレビューに書き込みマークを表示するか
     show_post_mark = cf.get_option_bool( "show_post_mark", CONF_SHOW_POST_MARK );
 
@@ -661,6 +670,7 @@ void ConfigItems::save_impl( const std::string& path )
 
     cf.update( "fontname_main", fontname[ FONT_MAIN ] );
     cf.update( "fontname_popup", fontname[ FONT_POPUP ] );
+    cf.update( "fontname_aa", fontname[ FONT_AA ] );
     cf.update( "fontname_bbs", fontname[ FONT_BBS ] );
     cf.update( "fontname_board", fontname[ FONT_BOARD ] );
     cf.update( "fontname_message", fontname[ FONT_MESSAGE ] );
@@ -668,6 +678,8 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "ref_prefix", ref_prefix );
     cf.update( "ref_prefix_space", ref_prefix_space );
 
+    cf.update( "regex_res_aa", regex_res_aa );
+
     cf.update( "path_cacheroot", path_cacheroot );
 
     cf.update( "agent_for2ch", agent_for2ch );
@@ -860,6 +872,10 @@ void ConfigItems::save_impl( const std::string& path )
 
     cf.update( "switchtab_wheel", switchtab_wheel );
 
+    cf.update( "newtab_pos", newtab_pos );
+
+    cf.update( "boardnexttab_pos", boardnexttab_pos );
+
     cf.update( "show_post_mark", show_post_mark );
 
     cf.update( "flat_button", flat_button );
@@ -936,6 +952,9 @@ void ConfigItems::set_fonts( JDLIB::ConfLoader& cf )
     // ポップアップのフォント
     fontname[ FONT_POPUP ] = cf.get_option_str( "fontname_popup", defaultfont + " " + std::string( CONF_FONTSIZE_POPUP ) );
 
+    // AA(スレビュー)のフォント
+    fontname[ FONT_AA ] = cf.get_option_str( "fontname_aa", fontname[ FONT_MAIN ] );
+
     // スレ一覧のフォント
     fontname[ FONT_BBS ] = cf.get_option_str( "fontname_bbs", defaultfont + " " + std::string( CONF_FONTSIZE_TREE ) );
 
