@@ -43,6 +43,9 @@ namespace CONFIG
         int ref_prefix_space;
         std::string ref_prefix_space_str;
 
+        // レスにアスキーアートがあると判定する正規表現
+        std::string regex_res_aa;
+
         // キャッシュのルートディレクトリ
         // 旧バージョンとの互換のため残しているだけで使用していない
         std::string path_cacheroot;
@@ -405,6 +408,9 @@ namespace CONFIG
         // ビュー内から他のビューを開いたときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
         int newtab_pos;
 
+        // 次スレ検索を開くときのタブの位置 ( 0: 次スレ検索タブ 1:新しいタブ 2:アクティブなタブを置き換え )
+        int boardnexttab_pos;
+
         // スレビューに書き込みマークを表示するか
         bool show_post_mark;
 
