@@ -103,6 +103,8 @@ namespace CONFIG
         CONF_TAB_MIN_STR = 4, // タブに表示する文字列の最小値
         CONF_SHOW_TAB_ICON = 1, // タブにアイコンを表示するか
         CONF_SWITCHTAB_WHEEL = 1, // タブ上でマウスホイールを回転してタブを切り替える
+        CONF_NEWTAB_POS = 1, // ビュー内から他のビューを開いたときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
+        CONF_BOARDNEXTTAB_POS = 0, // 次スレ検索を開くときのタブの位置 ( 0: 次スレ検索タブ 1:新しいタブ 2:アクティブなタブを置き換え )
         CONF_SHOW_POST_MARK = 1, // スレビューに書き込みマークを表示するか
         CONF_FLAT_BUTTON = 1,    // ボタンをフラットにするか
         CONF_DRAW_TOOLBARBACK = 0, // ツールバーの背景描画
@@ -179,6 +181,9 @@ namespace CONFIG
 // レスを参照するときに前に付ける文字
 #define CONF_REF_PREFIX ">"
 
+// レスにアスキーアートがあると判定する正規表現
+#define CONF_REGEX_RES_AA "\"　 \""
+
 // キャッシュのルートディレクトリ(旧バージョンとの互換のため残している)
 #define CONF_PATH_CACHEROOT "~/.jd/"
 
@@ -186,7 +191,7 @@ namespace CONFIG
 #define CONF_AGENT_FOR2CH "Monazilla/1.00 JD"
 
 // 2ch外にアクセスするときのエージェント名
-#define CONF_AGENT_FOR_DATA "Mozilla/5.0 (Windows; U; Windows NT 5.0; ja; rv:1.9) Gecko/2008052906 Firefox/3.0"
+#define CONF_AGENT_FOR_DATA "Monazilla/1.00 JD"
 
 // 2ch にログインするときのX-2ch-UA
 #define CONF_X_2CH_UA "Navigator for 2ch 1.7.5"
