@@ -155,7 +155,6 @@ void BoardJBBS::parse_subject( const char* str_subject_txt )
 #endif 
    
     const char* pos = str_subject_txt;
-    char str_tmp[ 1024 ];
 
     while( *pos != '\0' ){
         
@@ -191,9 +190,13 @@ void BoardJBBS::parse_subject( const char* str_subject_txt )
         // レス数取得
         ++pos;
         int i = 0;
-        while( *pos != ')' && *pos != '\0' && *pos != '\n' && i < 16 ) str_num[ i++ ] = *( pos++ );
+        while( '0' <= *pos && *pos <= '9' && i < 16 ) str_num[ i++ ] = *( pos++ );
 
         // 壊れてる
+        if( i == 0 ){
+            MISC::ERRMSG( "subject.txt is broken (res)" );
+            break;
+        }
         if( *pos == '\0' ) break;
         if( *pos == '\n' ) { ++pos; continue; }
 
@@ -203,13 +206,11 @@ void BoardJBBS::parse_subject( const char* str_subject_txt )
         // id, subject, number 取得
         ARTICLE_INFO artinfo;
 
-        memcpy( str_tmp, str_id_dat, lng_id_dat );
-        str_tmp[ lng_id_dat ] = '\0';
-        artinfo.id = MISC::remove_space( str_tmp );
+        artinfo.id.assign( str_id_dat, lng_id_dat );
+        artinfo.id = MISC::remove_space( artinfo.id );
 
-        memcpy( str_tmp, str_subject, lng_subject );
-        str_tmp[ lng_subject ] = '\0';
-        artinfo.subject = MISC::remove_space( str_tmp );
+        artinfo.subject.assign( str_subject, lng_subject );
+        artinfo.subject = MISC::remove_space( artinfo.subject );
         artinfo.subject = MISC::replace_str( artinfo.subject, "&lt;", "<" );
         artinfo.subject = MISC::replace_str( artinfo.subject, "&gt;", ">" );
         
