@@ -7,12 +7,8 @@
 #ifndef _IMAGEAREAICON_H
 #define _IMAGEAREAICON_H
 
-#include "skeleton/dispatchable.h"
-
 #include "imageareabase.h"
 
-#include <pthread.h>
-
 namespace IMAGE
 {
     // m_imagetype にセットする値
@@ -23,9 +19,8 @@ namespace IMAGE
     };
 
 
-    class ImageAreaIcon : public ImageAreaBase, public SKELETON::Dispatchable
+    class ImageAreaIcon : public ImageAreaBase
     {
-        pthread_t m_thread;
         bool m_shown;
         int m_imagetype; // dispatch()前に表示する画像を入れる
 
@@ -40,14 +35,17 @@ namespace IMAGE
         virtual ~ImageAreaIcon();
 
         virtual void show_image();
-        void show_image_thread();
+
+        virtual void load_image_thread();
 
       private:
 
-        void wait();
+        const int width_indicator();
+        const int height_indicator();
+
         void show_indicator( bool loading );
-        virtual void callback_dispatch();
-        void set_image();
+
+        virtual void set_image();
     };
 }
 
