@@ -153,10 +153,10 @@ void Admin::setup_menu()
     m_action_group->add( Gtk::Action::create( "ReloadAll", "再読み込み(_R)" ), sigc::mem_fun( *this, &Admin::slot_reload_all_tabs ) );
     m_action_group->add( Gtk::Action::create( "CancelReloadAll", "キャンセル(_C)" ), sigc::mem_fun( *this, &Admin::slot_cancel_reload_all_tabs ) );
 
-    m_action_group->add( Gtk::Action::create( "OpenBrowser", ITEM_NAME_OPEN_BROWSER + std::string( "(_W)" ) ),
+    m_action_group->add( Gtk::Action::create( "OpenBrowser", ITEM_NAME_OPEN_BROWSER "(_W)" ),
                          sigc::mem_fun( *this, &Admin::slot_open_by_browser ) );
-    m_action_group->add( Gtk::Action::create( "CopyURL", ITEM_NAME_COPY_URL + std::string( "(_U)" ) ), sigc::mem_fun( *this, &Admin::slot_copy_url ) );
-    m_action_group->add( Gtk::Action::create( "CopyTitleURL", ITEM_NAME_COPY_TITLE_URL + std::string( "(_L)" ) ),
+    m_action_group->add( Gtk::Action::create( "CopyURL", ITEM_NAME_COPY_URL "(_U)" ), sigc::mem_fun( *this, &Admin::slot_copy_url ) );
+    m_action_group->add( Gtk::Action::create( "CopyTitleURL", ITEM_NAME_COPY_TITLE_URL "(_L)" ),
                          sigc::mem_fun( *this, &Admin::slot_copy_title_url ) );
 
     m_action_group->add( Gtk::Action::create( "Preference", "プロパティ(_P)..."), sigc::mem_fun( *this, &Admin::show_preference ) );
@@ -944,29 +944,26 @@ void Admin::update_status( View* view, const bool force )
 //
 // command.arg1: 開く位置
 //
-// "false" ならアクティブなタブを置き換える
+// "false" ならアクティブなタブを置き換える ( デフォルト )
 // "true" なら一番右側に新しいタブを開く
 // "right" ならアクティブなタブの右に開く
 // "newtab" なら設定によってアクティブなタブの右に開くか一番右側に開くか切り替える
 // "left" ならアクティブなタブの左に開く
 // "page数字" なら指定した位置にタブで開く
+// "replace" なら arg3 に指定したタブがあれば置き換え、なければ "newtab" で動作する
 //
 // command.arg2: "true" なら既に command.url を開いているかチェックしない
 //
 // command.arg3: モード  ( 複数指定する場合は空白で空ける )
 //
 // "auto"なら表示されていればリロードせずに切替える
-// されていなければarg1で指定した場所に新しいタブで開いてロード
-// スレ番号ジャンプなどで使用する
-//
+//     されていなければarg1で指定した場所に新しいタブで開いてロード
+//     スレ番号ジャンプなどで使用する
 // "noswitch"ならタブを切り替えない(連続して開くときに使用)
-//
 // "lock" なら開いてからロックする
-//
 // "offline" なら オフラインで開く
-//
 // "reget" なら読み込み時にキャッシュ等を消してから再読み込みする
-//
+// "boardnext" など、 "replace" で置き換えるタブの種類を指定する
 //
 // その他のargは各ビュー別の設定
 //
@@ -1032,12 +1029,43 @@ void Admin::open_view( const COMMAND_ARGS& command )
         }
     }
 
+    // 開く位置の基準を、アクティブなタブに仮定
+    int page = m_notebook->get_current_page();
+
+    std::string open_method = command.arg1;
+    if( open_method.empty() ){
+        open_method = "false";
+    }
+
+    // 置き替えるページを探す
+    if( open_method == "replace" ){
+        // 該当するタブが見つからない場合のために、新しいタブで開くモードに仮設定
+        open_method = "newtab";
+
+        // タブの種類 (command.arg3) に該当するタブを探す
+        int find_page = find_view( command.arg3 );
+#ifdef _DEBUG
+        std::cout << "replace mode = " << command.arg3
+                << " page = " << page << " find = " << find_page << std::endl;
+#endif
+        if( find_page >= 0 ){
+            SKELETON::View* found_view = dynamic_cast< View* >( m_notebook->get_nth_page( page ) );
+            if( found_view ){
+                // 指定したタブを置き換えるモードに設定
+                open_method = "false";
+
+                // 開く位置の基準を、見つかったタブに設定
+                page = find_page;
+                current_view = found_view;
+            }
+        }
+    }
+
     view = create_view( command );
     if( !view ) return;
 
-    const int page = m_notebook->get_current_page();
     const bool open_tab = (  page == -1
-                             || ( ! command.arg1.empty() && command.arg1 != "false" )
+                             || open_method != "false"
                              || ( mode & OPEN_MODE_AUTO ) // オートモードの時もタブで開く
                              || is_locked( page )
         );
@@ -1051,10 +1079,10 @@ void Admin::open_view( const COMMAND_ARGS& command )
         int openpage = -1;
 
         // 現在のページの右に表示
-        if( command.arg1 == "right" ) openpage = page +1;
+        if( open_method == "right" ) openpage = page +1;
 
         // 設定によって切り替える
-        if( command.arg1 == "newtab" ){
+        if( open_method == "newtab" ){
             switch( CONFIG::get_newtab_pos() ){
                 case 1:  openpage = page +1; break;
                 case 2:  openpage = page; break;
@@ -1062,16 +1090,16 @@ void Admin::open_view( const COMMAND_ARGS& command )
         }
 
         // 現在のページの左に表示
-        else if( command.arg1 == "left" ) openpage = page;
+        else if( open_method == "left" ) openpage = page;
 
         // 指定した位置に表示
-        else if( command.arg1.find( "page" ) == 0 ) openpage = atoi( command.arg1.c_str() + 4 );
+        else if( open_method.find( "page" ) == 0 ) openpage = atoi( open_method.c_str() + 4 );
 
         // ロックされていたら右に表示
-        else if( command.arg1 != "true" && page != -1 && is_locked( page ) ) openpage = page +1;
+        else if( open_method != "true" && page != -1 && is_locked( page ) ) openpage = page +1;
 
 #ifdef _DEBUG
-        std::cout << "append page = " << openpage << std::endl;
+        std::cout << "append openpage = " << openpage << " / page = " << page << std::endl;
 #endif
 
 
@@ -1451,7 +1479,8 @@ void Admin::close_view( SKELETON::View* view )
     if( page == current_page ){
 
         // その前に開いていたビューに切り替える
-        if( m_use_switchhistory && m_list_switchhistory.size() ) switch_view( m_list_switchhistory.back() );
+        const std::string hist_url = get_valid_switchhistory();
+        if( ! hist_url.empty() ) switch_view( hist_url );
 
         // もし現在表示中のビューを消すときは予めひとつ右のビューにスイッチしておく
         // そうしないと左のビューを一度表示してしまうので遅くなる
@@ -2797,3 +2826,39 @@ void Admin::remove_switchhistory( const std::string& url )
     }
 #endif
 }
+
+
+//
+// タブの切り替え履歴から、有効な最後のURLを返す
+//
+// 表示されているビューに存在しないURLは履歴から削除して、表示されているビューのURLを返す。
+// 見つからないときは空文字列を返す。
+//
+// NOTE:
+//   タブの切り替え履歴にあるビューは、表示されているビューのうちのどれかであるはずだが、
+//   検索ビューなどでURLが変更になる場合があり、 ( View::set_url()で変更できてしまう。 )
+//   タブの切り替え履歴にあるURLと、表示されているビューのURLが不一致となることがある。
+//   また、その不一致なタブの切り替え履歴を、セッション情報 ( article_switchhistoryなど ) に
+//   保存してしまっていたため、ここで不一致な履歴の削除を行うことで、履歴を修復する。
+//
+const std::string Admin::get_valid_switchhistory()
+{
+    if( ! m_use_switchhistory ) return std::string();
+
+    while( m_list_switchhistory.size() > 0 ){
+
+        // タブの切り替え履歴から、最後のURLを取り出す
+        const std::string url = m_list_switchhistory.back();
+
+        // 表示されているビューであれば、そのURLを返す
+        SKELETON::View* view = get_view( url );
+        if( view ) return url;
+
+        // 表示されていないので、最後のURLを削除する
+        m_list_switchhistory.pop_back();
+#ifdef _DEBUG
+        std::cout << "Admin::get_valid_switchhistory remove = " << url << std::endl;
+#endif
+    }
+    return std::string();
+}
